/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SimpleInterface.java 4340 2008-12-03 21:44:57Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.osgi;

import java.util.List;
import java.util.Properties;

import javax.ejb.Remote;

/**
 * Simple remote interface for the Bean.
 * @author Florent BENOIT
 */
@Remote
public interface SimpleInterface {

    /**
     * @return the list of all OSGi Bundles symbolic names found on the gateway.
     */
    List<String> listOSGiSymbolicNameBundles();

    /**
     * Try to log on the OSGi Log service.
     * @return result of the commands.
     */
    String tryLogService();

    /**
     * See how many services of the given class have been registered in OSGi.
     * @param objectClass service interface name
     * @return the number of services (matching the objectClass parameter) registered in OSGi
     */
    int getNumberOfRegisteredServices(String objectClass);

    /**
     * A test method checking if the dependency has been injected in the field.
     * @return <code>true</code> if injected
     */
    boolean isDependencyFieldInjected();

    /**
     * A test method checking if the dependency has been injected through the methods.
     * @return <code>true</code> if injected
     */
    boolean isDependencyMethodInjected();

    /**
     * This method throws a runtime exception.
     */
    void throwIllegalStateException();

    /**
     * Update the service with the given properties set.
     * @param properties new service properties
     */
    void updateConfigurationProperties(String pid, Properties properties);

    /**
     * @param pid Service PID
     * @param propertyName property name to be retrieve
     * @return the value of the property associated with te given pid (may return null).
     */
    String getServiceProperty(String pid, String propertyName);

    /**
     * @param containerSymbolicName symbolic name of the EjbJar bundle
     * @return <code>true</code> if the EZBContainer service with the
     *         given name has been found.
     */
    boolean isEZBContainerAvailable(String containerSymbolicName);
}
